local mod = ...



-- Spawn orientations
local orientationMin = { 0, 0, 0, 1 }
local orientationMax = { 0, 0, 0, 1 }
quaternion.setEulerAngles(orientationMin, { 0, -180, 0 })
quaternion.setEulerAngles(orientationMax, { 0, 180, 0 })


-- registering map files
mod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mod:registerAssetId("maps/rock_density.png", "ROCK_DENSITY_MAP")
-- mod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")
mod:registerAssetId("maps/tree_density_map1.png", "TREE_DENSITY_MAP1")
mod:registerAssetId("maps/tree_density_map2.png", "TREE_DENSITY_MAP2")
mod:registerAssetId("maps/desert_density_map.png", "DESERT_DENSITY_MAP")


-- register custom map
mod:registerAsset({
	DataType = "CUSTOM_MAP",
	Id = "MAP_SAHRAJAMILA",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = 0,
	MaxHeight = 34,
	VillagePathList = {
		{
			Entrance = { 100, 0, 1013 },
			Exit = { 100, 0, 13 },
		},
		{
			Entrance = { 200, 0, 1013 },
			Exit = { 200, 0, 13 },
		},
		{
			Entrance = { 300, 0, 1013 },
			Exit = { 300, 0, 13 },
		},
		{
			Entrance = { 400, 0, 1013 },
			Exit = { 400, 0, 13 },
		},
		{
			Entrance = { 500, 0, 1013 },
			Exit = { 500, 0, 13 },
		},
		{
			Entrance = { 600, 0, 1013 },
			Exit = { 600, 0, 13 },
		},
		{
			Entrance = { 700, 0, 1013 },
			Exit = { 700, 0, 13 },
		},
		{
			Entrance = { 800, 0, 1013 },
			Exit = { 800, 0, 13 },
		},
		{
			Entrance = { 900, 0, 1013 },
			Exit = { 900, 0, 13 },
		}
	},
    SpawnList = {
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 785, 14, 363 },
            Orientation = { 0 , 84, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 839, 21, 420 },
            Orientation = { 0 , 146, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 775, 22, 225 },
            Orientation = { 0 , 97, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 380, 24, 142 },
            Orientation = { 0 , -55, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 236, 20, 475 },
            Orientation = { 0 , -71, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 135, 24, 751 },
            Orientation = { 0 , -50, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 568, 20, 795 },
            Orientation = { 0 , -14, 0 },
        },
	},
	DensitySpawnList = {
        {
			DensityMap = "TREE_DENSITY_MAP1",
			Density = 0.5,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM1" },
                    RandomWeight = 3.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.35
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM2" },
                    RandomWeight = 5.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.75
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_DATE" },
                    RandomWeight = 0.5,
                    OffsetSizeRange = {
                        Min = 0.90,
                        Max = 1.10
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_CANE" },
                    RandomWeight = 2.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
            },
		},
        {
			DensityMap = "TREE_DENSITY_MAP2",
			Density = 0.4,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_DATE" },
                    RandomWeight = 0.75,
                    OffsetSizeRange = {
                        Min = 0.20,
                        Max = 1.10
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_CANE" },
                    RandomWeight = 10,
                    OffsetSizeRange = {
                        Min = 1.0,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM2" },
                    RandomWeight = 0.10,
                    OffsetSizeRange = {
                        Min = 0.4,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
                -- {
                --     PrefabList = { "PREFAB_TROPICAL_FLOWER1" },
                --     RandomWeight = 3.0,
                --     OffsetSizeRange = {
                --         Min = 0.85,
                --         Max = 1.15
                --     },
                --         OrientationRange = {
                --             Min = orientationMin,
                --             Max = orientationMax,
                --     },
                --         ScaleRange = {
                --             Min = 0.7,
                --             Max = 1.3
                --     },
                --         ColorRange = {
                --             Min = { 0.55, 0.55, 0.72, 1 },
                --             Max = { 0.65, 0.65, 0.72, 1 }
                --     }
				-- },
                -- {
                --     PrefabList = { "PREFAB_TROPICAL_FLOWER2" },
                --     RandomWeight = 2.5,
                --     OffsetSizeRange = {
                --         Min = 0.85,
                --         Max = 1.15
                --     },
                --         OrientationRange = {
                --             Min = orientationMin,
                --             Max = orientationMax,
                --     },
                --         ScaleRange = {
                --             Min = 0.7,
                --             Max = 1.3
                --     },
                --         ColorRange = {
                --             Min = { 0.55, 0.55, 0.72, 1 },
                --             Max = { 0.65, 0.65, 0.72, 1 }
                --     }
				-- },
                -- {
                --     PrefabList = { "PREFAB_TROPICAL_FLOWER3" },
                --     RandomWeight = 2.5,
                --     OffsetSizeRange = {
                --         Min = 0.85,
                --         Max = 1.15
                --     },
                --         OrientationRange = {
                --             Min = orientationMin,
                --             Max = orientationMax,
                --     },
                --         ScaleRange = {
                --             Min = 0.7,
                --             Max = 1.3
                --     },
                --         ColorRange = {
                --             Min = { 0.55, 0.55, 0.72, 1 },
                --             Max = { 0.65, 0.65, 0.72, 1 }
                --     }
				-- },
                -- {
                --     PrefabList = { "PREFAB_TROPICAL_FLOWER4" },
                --     RandomWeight = 2.5,
                --     OffsetSizeRange = {
                --         Min = 0.85,
                --         Max = 1.15
                --     },
                --         OrientationRange = {
                --             Min = orientationMin,
                --             Max = orientationMax,
                --     },
                --         ScaleRange = {
                --             Min = 0.7,
                --             Max = 1.3
                --     },
                --         ColorRange = {
                --             Min = { 0.55, 0.55, 0.72, 1 },
                --             Max = { 0.65, 0.65, 0.72, 1 }
                --     }
				-- },
            },
		},
        {
			DensityMap = "DESERT_DENSITY_MAP",
			Density = 0.75,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_IRRIGATION_DESERT" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.5,
                        Max = 1.5,
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.5,
                            Max = 1.0,
                    },
                        ColorRange = {
                            Min = { 1, 1, 1, 1 },
                            Max = { 1, 1, 1, 1 },
                    }
				},
            },
		},
        {
			-- Create rock outcrops - stone resource
			DensityMap = "ROCK_DENSITY_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_ROCK" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = orientationMin,
							Max = orientationMax,
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		-- {
		-- 	-- Create fish shoals
		-- 	DensityMap = "FISH_DENSITY_MAP",
		-- 	Density =0.9,
		-- 	PrefabConfigList = {
		-- 		{
		-- 				PrefabList = { "PREFAB_RESOURCE_FISH" },
		-- 				RandomWeight = 0.1,
		-- 				OffsetSizeRange = {
		-- 					Min = 0.75,
		-- 					Max = 1.0
		-- 			},
		-- 				OrientationRange = {
		-- 					Min = { 0, -180, 0 },
		-- 					Max = { 0, 180, 0 }
		-- 			},
		-- 				ScaleRange = {
		-- 					Min = 0.85,
		-- 					Max = 1.15
		-- 			},
		-- 				ColorRange = {
		-- 					Min = { 0.8, 0.8, 0.8, 1 },
		-- 					Max = { 1, 1, 1, 1 }
		-- 			}
		-- 		}
		-- 	}
		-- },
	},
})
-- This map was created with the help of the UFME
